[![CI](https://github.com/fhswf/MLPro-Int-MuJoCo/actions/workflows/ci.yml/badge.svg)](https://github.com/fhswf/MLPro-Int-MuJoCo/actions/workflows/ci.yml)
[![Documentation Status](https://readthedocs.org/projects/mlpro-int-mujoco/badge/?version=latest)](https://mlpro-int-mujoco.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/mlpro-int-mujoco.svg)](https://badge.fury.io/py/mlpro-int-mujoco)
<!---
[![Anaconda-Version Badge](https://anaconda.org/mlpro-int-mujoco/mlpro-int-mujoco/badges/version.svg)](https://anaconda.org/mlpro-int-mujoco/mlpro)
[![Anaconda-Downloads Badge](https://img.shields.io/conda/dn/mlpro-int-mujoco/mlpro-int-mujoco?color=green&label=Anaconda.org%20Total%20downloads&style=flat-square)](https://anaconda.org/mlpro-int-mujoco/mlpro-int-mujoco)
--->
[![PyPI Total Downloads](https://static.pepy.tech/personalized-badge/mlpro-int-mujoco?period=total&units=international_system&left_color=blue&right_color=orange&left_text=PyPI%20Total%20Downloads)](https://pepy.tech/project/mlpro-int-mujoco)
[![PyPI Last Month Downloads](https://static.pepy.tech/personalized-badge/mlpro-int-mujoco?period=month&units=international_system&left_color=blue&right_color=orange&left_text=PyPI%20Last%20Month%20Downloads)](https://pepy.tech/project/mlpro-int-mujoco)


<img src="https://github.com/fhswf/MLPro-Int-MuJoCo/blob/main/doc/logo/original/logo.png?raw=True" align="right" width="40%"/>

# MLPro-Int-MuJoCo - Integration between MuJoCo and MLPro
Welcome to MLPro-Int-MuJoCo, an extension to MLPro to integrate the MuJoCo package. MLPro is a middleware framework for standardized machine learning in Python. It is developed by the South Westphalia University of Applied Sciences, Germany, and provides standards, templates, and processes for hybrid machine learning applications. MuJoCo (Multi-Joint dynamics with Contact), in turn, is a physics engine primarily used for simulating and optimizing complex robotic systems and physical interactions in various fields such as robotics, biomechanics, and machine learning.

MLPro-Int-MuJoCo offers wrapper classes that allow the reuse of functionalities from MuJoCo in MLPro.

### Learn more
[MLPro - Machine Learning Professional](https://mlpro.readthedocs.io)   
[MLPro-Int-MuJoCo - Integration of MuJoCo into MLPro](https://mlpro-int-mujoco.readthedocs.io)   
[MuJoCo - Advanced Physics Simulation](https://mujoco.org/)   